Interface for message content (body) that contains the actual message data.
Represents the core payload of a message, including type identifier, metadata,
and message-specific data (text, commands, etc.). Implements Mapper for
serialization to/from structured formats (Map/JSON).
Serialized format (Map/JSON):
{
"type": "0", // Message type (e.g., i2s(0) = "0" = "text")
"sn": 0, // Unique serial number (serves as message ID)
"time": 123.45, // Message timestamp (Unix timestamp in seconds)
"group": "group@zzz", // Optional group ID (marks this as a group message)
//-- message info
"text": "Hello World!", // Text content (for text messages)
"command": "handshake" // Command name (for system command messages)
//...
}
Properties
-
entries
→ Iterable<
MapEntry< String, dynamic> > -
The map entries of this Map.
no setterinherited
- group ↔ ID?
-
Group identifier for group messages.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
Whether there is no key/value pair in the map.
no setterinherited
- isNotEmpty → bool
-
Whether there is at least one key/value pair in the map.
no setterinherited
-
keys
→ Iterable<
String> -
The keys of this Map.
no setterinherited
- length → int
-
The number of key/value pairs in the map.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sn → int
-
Serial number (unique message identifier).
no setter
- time → DateTime?
-
Timestamp when the content was created.
no setter
- type → String
-
Message type identifier.
no setter
- values → Iterable
-
The values of this Map.
no setterinherited
Methods
-
addAll(
Map< String, dynamic> other) → void -
Adds all key/value pairs of
otherto this map.inherited -
addEntries(
Iterable< MapEntry< newEntries) → voidString, dynamic> > -
Adds all key/value pairs of
newEntriesto this map.inherited -
cast<
RK, RV> () → Map< RK, RV> -
Provides a view of this map as having
RKkeys andRVinstances, if necessary.inherited -
clear(
) → void -
Removes all entries from the map.
inherited
-
containsKey(
Object? key) → bool -
Whether this map contains the given
key.inherited -
containsValue(
Object? value) → bool -
Whether this map contains the given
value.inherited -
copyMap(
[bool deepCopy = false]) → Map -
Creates a copy of the internal map.
inherited
-
forEach(
void action(String key, dynamic value)) → void -
Applies
actionto each key/value pair of the map.inherited -
getBool(
String key, [bool? defaultValue]) → bool? -
inherited
-
getDateTime(
String key, [DateTime? defaultValue]) → DateTime? -
inherited
-
getDouble(
String key, [double? defaultValue]) → double? -
inherited
-
getInt(
String key, [int? defaultValue]) → int? -
inherited
-
getString(
String key, [String? defaultValue]) → String? -
Gets a string value for the given key.
inherited
-
map<
K2, V2> (MapEntry< K2, V2> convert(String key, dynamic value)) → Map<K2, V2> -
Returns a new map where all entries of this map are transformed by
the given
convertfunction.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putIfAbsent(
String key, dynamic ifAbsent()) → dynamic -
Look up the value of
key, or add a new entry if it isn't there.inherited -
remove(
Object? key) → dynamic -
Removes
keyand its associated value, if present, from the map.inherited -
removeWhere(
bool test(String key, dynamic value)) → void -
Removes all entries of this map that satisfy the given
test.inherited -
setDateTime(
String key, DateTime? time) → void -
inherited
-
setMap(
String key, Mapper? mapper) → void -
inherited
-
setString(
String key, Stringer? stringer) → void -
inherited
-
toMap(
) → Map -
Returns the internal map as a Map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
String key, dynamic update(dynamic value), {dynamic ifAbsent()?}) → dynamic -
Updates the value for the provided
key.inherited -
updateAll(
dynamic update(String key, dynamic value)) → void -
Updates all values.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
Object? key) → dynamic -
The value for the given
key, ornullifkeyis not in the map.inherited -
operator []=(
String key, dynamic value) → void -
Associates the
keywith the givenvalue.inherited
Static Methods
-
convert(
Iterable array) → List< Content> -
getFactory(
String msgType) → ContentFactory? -
parse(
Object? content) → Content? -
revert(
Iterable< Content> contents) → List<Map> -
setFactory(
String msgType, ContentFactory factory) → void