type property
String?
get
type
Message content type identifier (for routing encrypted content).
Purpose: Since message content may be encrypted, intermediate nodes (e.g., stations) cannot parse the content to determine its type. This field exposes the content type in plaintext to enable proper routing/processing by network nodes.
Examples: "text", "file", "command", ...
Implementation
String? get type;
set
type
(String? msgType)
Implementation
set type(String? msgType);